Use db_browser_ui() and db_browser_server()
to include the data lake browser as a Shiny module in your own app.
See also
Other shiny:
db_browser(),
db_browser_ui()
Use db_browser_ui() and db_browser_server()
to include the data lake browser as a Shiny module in your own app.
Other shiny:
db_browser(),
db_browser_ui()