Skip to contents

Returns information about all tables in the connected DuckLake catalog, including row counts, file counts, and storage statistics.

Usage

db_catalog()

Value

A data.frame of table information

Examples

if (FALSE) { # \dontrun{
db_lake_connect()
db_catalog()
} # }