Skip to contents

Lists all entries published to the discovery catalog. This works even if you don't have access to the underlying data, allowing organisation-wide data discovery.

This function is only available in hive mode. In DuckLake mode, use db_dictionary() for data discovery, with access controlled via schema paths.

Usage

db_list_public(section = NULL)

Arguments

section

Optional section to filter by

Value

A data.frame with discovery information

Examples

if (FALSE) { # \dontrun{
db_connect("//CSO-NAS/DataLake")
db_list_public()
db_list_public(section = "Trade")
} # }