Returns information about the current connection state, including mode (hive/ducklake), paths, and connection validity.
Examples
if (FALSE) { # \dontrun{
db_lake_connect()
db_status()
} # }
Returns information about the current connection state, including mode (hive/ducklake), paths, and connection validity.
if (FALSE) { # \dontrun{
db_lake_connect()
db_status()
} # }