Returns information about all tables in the connected DuckLake catalog, including row counts, file counts, and storage statistics.
Examples
if (FALSE) { # \dontrun{
db_lake_connect()
db_catalog()
} # }
Returns information about all tables in the connected DuckLake catalog, including row counts, file counts, and storage statistics.
if (FALSE) { # \dontrun{
db_lake_connect()
db_catalog()
} # }