Scans the public catalog and updates entries from their source metadata. Optionally removes entries where the source no longer exists.
This function is only available in hive mode.
Examples
if (FALSE) { # \dontrun{
db_connect("//CSO-NAS/DataLake")
db_sync_catalog()
db_sync_catalog(remove_orphans = TRUE)
} # }